### PyBreweryDB

This is a Python wrapper around the BreweryDB API.  It is a work in progress with
only a handful of endpoints implemented at this point.

Pre-release builds are available on Github only at this point.  Future builds
will be released on Pypi.

### Authors

* Derek Stegelman

Heavily inspried and several linez of codez drawn from PyMarvel by @gpennington